package com.amap.api.maps.utils.overlay;

package ..deTemp.1733461613224;

import com.amap.api.col.3sl.dx;
import com.amap.api.col.3sl.ly;
import com.amap.api.col.3sl.lz;
import com.amap.api.maps.AMap;
import com.amap.api.maps.AMapUtils;
import com.amap.api.maps.model.BasePointOverlay;
import com.amap.api.maps.model.CameraPosition;
import com.amap.api.maps.model.LatLng;
import com.autonavi.amap.mapcore.IPoint;
import com.autonavi.amap.mapcore.MapProjection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;

public class MovingPointOverlay {
  private AMap mAMap;
  
  private long duration = 10000L;
  
  private long mStepDuration = 20L;
  
  private LinkedList<LatLng> points = new LinkedList<LatLng>();
  
  private LinkedList<Double> eachDistance = new LinkedList<Double>();
  
  private double totalDistance = 0.0D;
  
  private double remainDistance = 0.0D;
  
  private ly mThreadPools;
  
  private Object mLock = new Object();
  
  private BasePointOverlay baseOverlay = null;
  
  private int index = 0;
  
  private boolean useDefaultDescriptor = false;
  
  AtomicBoolean exitFlag = new AtomicBoolean(false);
  
  private MoveListener moveListener;
  
  private a STATUS = a.a;
  
  private long pauseMillis;
  
  private long mAnimationBeginTime = System.currentTimeMillis();
  
  public MovingPointOverlay(AMap paramAMap, BasePointOverlay paramBasePointOverlay) {
    if (paramAMap == null || paramBasePointOverlay == null)
      return; 
    this.mAMap = paramAMap;
    this.mThreadPools = dx.a("AMapMoveSmoothThread");
    this.baseOverlay = paramBasePointOverlay;
  }
  
  public void setPoints(List<LatLng> paramList) {
    synchronized (this.mLock) {
      try {
        if (paramList == null || paramList.size() < 2)
          return; 
        stopMove();
        this.points.clear();
        for (Iterator<LatLng> iterator = paramList.iterator(); iterator.hasNext();) {
          if ((latLng1 = iterator.next()) != null)
            this.points.add(latLng1); 
        } 
        this.eachDistance.clear();
        this.totalDistance = 0.0D;
        for (byte b = 0; b < this.points.size() - 1; b++) {
          double d = AMapUtils.calculateLineDistance(this.points.get(b), this.points.get(b + 1));
          this.eachDistance.add(Double.valueOf(d));
          this.totalDistance += d;
        } 
        this.remainDistance = this.totalDistance;
        LatLng latLng = this.points.get(0);
        this.baseOverlay.setPosition(latLng);
        reset();
      } catch (Throwable throwable) {
        null.printStackTrace();
      } 
      return;
    } 
  }
  
  private void reset() {
    try {
      if (this.STATUS == a.c || this.STATUS == a.d) {
        this.exitFlag.set(true);
        this.mThreadPools.a(this.mStepDuration + 20L, TimeUnit.MILLISECONDS);
        this.baseOverlay.setAnimation(null);
        this.STATUS = a.a;
      } 
      return;
    } catch (Exception exception) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void resetIndex() {
    this.index = 0;
  }
  
  public void setTotalDuration(int paramInt) {
    this.duration = (paramInt * 1000);
  }
  
  public void startSmoothMove() {
    if (this.STATUS == a.d) {
      this.STATUS = a.c;
      long l = System.currentTimeMillis() - this.pauseMillis;
      this.mAnimationBeginTime += l;
      return;
    } 
    if (this.STATUS == a.a || this.STATUS == a.e) {
      if (this.points.size() <= 0)
        return; 
      this.index = 0;
      try {
        this.mThreadPools.a((lz)new b(this, (byte)0));
        return;
      } catch (Throwable throwable) {
        null.printStackTrace();
      } 
    } 
  }
  
  private IPoint getCurPosition(long paramLong) {
    if (paramLong > this.duration) {
      this.exitFlag.set(true);
      IPoint iPoint = new IPoint();
      this.index = this.points.size() - 1;
      LatLng latLng = this.points.get(this.index);
      this.index--;
      this.index = Math.max(this.index, 0);
      this.remainDistance = 0.0D;
      MapProjection.lonlat2Geo(latLng.longitude, latLng.latitude, iPoint);
      if (this.moveListener != null)
        this.moveListener.move(this.remainDistance); 
      return iPoint;
    } 
    double d1 = paramLong * this.totalDistance / this.duration;
    this.remainDistance = this.totalDistance - d1;
    byte b1 = 0;
    double d2 = 1.0D;
    for (byte b2 = 0; b2 < this.eachDistance.size(); b2++) {
      double d = ((Double)this.eachDistance.get(b2)).doubleValue();
      if (d1 > d) {
        d1 -= d;
      } else {
        if (d > 0.0D)
          d2 = d1 / d; 
        b1 = b2;
        break;
      } 
    } 
    if (b1 != this.index && 
      this.moveListener != null)
      this.moveListener.move(this.remainDistance); 
    this.index = b1;
    LatLng latLng1 = this.points.get(b1);
    LatLng latLng2 = this.points.get(b1 + 1);
    IPoint iPoint2 = new IPoint();
    MapProjection.lonlat2Geo(latLng1.longitude, latLng1.latitude, iPoint2);
    IPoint iPoint1 = new IPoint();
    MapProjection.lonlat2Geo(latLng2.longitude, latLng2.latitude, iPoint1);
    int i = iPoint1.x - iPoint2.x;
    int j = iPoint1.y - iPoint2.y;
    if (AMapUtils.calculateLineDistance(latLng1, latLng2) > 
      
      1.0F) {
      float f = getRotate(iPoint2, iPoint1);
      CameraPosition cameraPosition;
      if (this.mAMap != null && (
        
        cameraPosition = this.mAMap.getCameraPosition()) != null)
        this.baseOverlay.setRotateAngle(360.0F - f + cameraPosition.bearing); 
    } 
    return new IPoint((int)(iPoint2.x + i * d2), (int)(iPoint2.y + j * d2));
  }
  
  private float getRotate(IPoint paramIPoint1, IPoint paramIPoint2) {
    if (paramIPoint1 == null || paramIPoint2 == null)
      return 0.0F; 
    double d1 = paramIPoint2.y;
    double d2 = paramIPoint1.y;
    double d3 = paramIPoint1.x;
    return (float)(Math.atan2(paramIPoint2.x - d3, d2 - d1) / Math.PI * 180.0D);
  }
  
  public void stopMove() {
    synchronized (this.mLock) {
      if (this.STATUS == a.c) {
        this.STATUS = a.d;
        this.pauseMillis = System.currentTimeMillis();
      } 
      return;
    } 
  }
  
  public BasePointOverlay getObject() {
    return this.baseOverlay;
  }
  
  public LatLng getPosition() {
    if (this.baseOverlay != null)
      return this.baseOverlay.getPosition(); 
    return null;
  }
  
  public int getIndex() {
    return this.index;
  }
  
  public void destroy() {
    try {
      removeMarker();
      this.mThreadPools.e();
      synchronized (this.mLock) {
        this.points.clear();
        this.eachDistance.clear();
        return;
      } 
    } catch (Throwable throwable) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void removeMarker() {
    try {
      reset();
      if (this.baseOverlay != null) {
        this.baseOverlay.remove();
        this.baseOverlay = null;
      } 
      this.points.clear();
      this.eachDistance.clear();
      return;
    } catch (Throwable throwable) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void setPosition(LatLng paramLatLng) {
    try {
      if (this.baseOverlay != null)
        this.baseOverlay.setPosition(paramLatLng); 
      return;
    } catch (Exception exception) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void setRotate(float paramFloat) {
    try {
      CameraPosition cameraPosition;
      if (this.baseOverlay != null && 
        this.mAMap != null && (
        
        cameraPosition = this.mAMap.getCameraPosition()) != null)
        this.baseOverlay.setRotateAngle(360.0F - paramFloat + cameraPosition.bearing); 
      return;
    } catch (Exception exception) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void setVisible(boolean paramBoolean) {
    try {
      if (this.baseOverlay != null)
        this.baseOverlay.setVisible(paramBoolean); 
      return;
    } catch (Exception exception) {
      null.printStackTrace();
      return;
    } 
  }
  
  public void setMoveListener(MoveListener paramMoveListener) {
    this.moveListener = paramMoveListener;
  }
}
